﻿using System;
using System.Net.Http;
using System.Threading.Tasks;
using System.Windows;

namespace SimpleBrowserAsync
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        // Adapted from http://stackoverflow.com/questions/14435520/why-use-httpclient-for-synchronous-connection
        private void GetSyncClicked(object sender, RoutedEventArgs e)
        {
            // Manually add reference for System.Net.Http
            OutputField.Text = "Working ...";
            String urlString = InputField.Text;
            if (String.IsNullOrWhiteSpace(urlString))
            {
                OutputField.Text = "Url is empty";
                return;
            }
            try
            {
                using (HttpClient httpClient = new HttpClient())
                {
                    Task<HttpResponseMessage> task = httpClient.GetAsync(urlString);
                    HttpResponseMessage response = task.Result;
                    response.EnsureSuccessStatusCode(); // throws exception if not success
                    Task<String> taskReader = response.Content.ReadAsStringAsync();
                    String body = taskReader.Result;
                    OutputField.Text = body;
                }
            }
            catch (HttpRequestException ex)
            {
                OutputField.Text = ex.ToString();
            }
        }

        // Adapted from http://msdn.microsoft.com/en-us/library/system.net.http.httpclient(v=vs.110).aspx
        private async void GetAsyncClicked(object sender, RoutedEventArgs e)
        {
            OutputField.Text = "Working ...";
            String urlString = InputField.Text;
            if (String.IsNullOrWhiteSpace(urlString))
            {
                OutputField.Text = "Url is empty";
                return;
            }
            // Manually add reference for System.Net.Http
            try
            {
                using (HttpClient httpClient = new HttpClient())
                {
                    HttpResponseMessage response = await httpClient.GetAsync(urlString);
                    response.EnsureSuccessStatusCode(); // throws exception if not success
                    String body = await response.Content.ReadAsStringAsync();
                    OutputField.Text = body;
                }
            }
            catch (HttpRequestException ex)
            {
                OutputField.Text = ex.Message;
            }
        }

        private void ClearClicked(object sender, RoutedEventArgs e)
        {
            OutputField.Text = "";
        }
    }
}
